package com.huimv.production.service.impl;

import com.huimv.production.domain.MSowFeed;
import com.huimv.production.domain.MSowHeat;
import com.huimv.production.repo.MSowHeatRepository;
import com.huimv.production.repo.MSowLivenessRepository;
import com.huimv.production.result.Result;
import com.huimv.production.result.ResultStatus;
import com.huimv.production.service.MSowHeatService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class MSowHeatServiceImpl implements MSowHeatService {

	@Autowired
	private MSowHeatRepository rep;

	@Override
	public Result add(MSowHeat entity){
		if (entity == null){
			return new Result(10002, ResultStatus.addNull);
		}
		try {
			rep.save(entity);
			return new Result(10000, ResultStatus.addSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.addFailed);
		}
	}

	@Override
	public Result remove(Integer[] ids) {
		if (ids == null || ids.length==0){
			return new Result(10002, ResultStatus.deleteNull);
		}
		try {
			for (Integer id : ids) {
				rep.deleteById(id);
			}
			return new Result(10000, ResultStatus.deleteSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.deleteFailed);
		}
	}

	@Override
	public Result update(MSowHeat entity) {
		if (entity == null){
			return new Result(10002, ResultStatus.updateNull);
		}
		try {
			rep.save(entity);
			return new Result(10000, ResultStatus.updateSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.updateFailed);
		}
	}

	@Override
	public Result findAll(String name ,Integer pageNum , Integer pageSize) {
		try {
			Map map = new HashMap();
			int size = rep.findAll().size() ;
			Integer startPage = (pageNum-1) * pageSize;
			List<MSowHeat> all = rep.findAll(name,startPage,pageSize);
			map.put("total",size);
			map.put("totalPageNum",(size  +  pageSize  - 1) / pageSize);
			map.put("data",all);
			return new Result(10000, ResultStatus.findSuccess,map);
		}catch (Exception e){
			return new Result(10001, ResultStatus.findFailed,null);
		}
	}

	@Autowired
	private MSowLivenessRepository livenessRepository;

	@Override
	public Result findAllBy(String sowId) {
		try {
			Map endMap = new HashMap();
			endMap.put("sowHeat",rep.findAllBySowCode(sowId));
			endMap.put("sowLiveness",livenessRepository.findAllBySowCode(sowId));


			return new Result(10000, ResultStatus.findSuccess,endMap);
		}catch (Exception e){
			return new Result(10001, ResultStatus.findFailed,null);
		}
	}
}
